Difficult Distance, Speed and time problems - Math Help Forum
Description: 1) A man takes 5 hrs and 45 mins to walk to a certain place and ride back. He would have gained 2 km by riding both ways. The time he would take to
Keywords: Difficult,Distance,Speed,time,problems,difficult, distance, problems, speed, time

- Register
- Help
- Save?

Results 1 to 2 of 2

# Math Help - Difficult Distance, Speed and time problems

- ###### LinkBack

  - LinkBack URL
  - About LinkBacks

- ###### Thread Tools

  - Show Printable Version
  - Subscribe to this Thread…

- ###### Display

  - Linear Mode
  - Switch to Hybrid Mode
  - Switch to Threaded Mode

1. December 21st 2009, 07:50 AM #1
   saberteeth
   Junior Member

   Joined
     Aug 2009
   Posts
     62

   ## Difficult Distance, Speed and time problems

   > 1) A man takes 5 hrs and 45 mins to walk to a certain place and ride back. He would have gained 2 km by riding both ways. The time he would take to walk both ways is?
   > 2) A jeep travels a distance of 100 km at a uniform speed. If the speed of the jeep is 5km/hr, then it takes 3 hrs to cover the same distance. Find the original speed of the jeep.
   > 3) A train overtakes two men walking in the same direction as the train at the speed of 3km/hr and 4.5km/he in 8 and 12 sec respectively. Find the length of the train.

   > Follow Math Help Forum on Facebook and Google+

2. December 22nd 2009, 04:52 AM #2
   mr fantastic
   Flow Master

   Joined
     Dec 2007
   From
     Zeitgeist
   Posts
     16,948
   Thanks
     5

   > Originally Posted by saberteeth
   > 1) A man takes 5 hrs and 45 mins to walk to a certain place and ride back. He would have gained 2 km by riding both ways. The time he would take to walk both ways is?
   > [snip]
   > .... (1)
   > .... (2) (assuming that when you typed 'gained 2 km' you meant 'gained 2 hours').
   > Substitute equation (2) into equation (1) and solve for
   > .

   > Follow Math Help Forum on Facebook and Google+

« Completing the square | math »

#### Similar Math Help Forum Discussions

1. ###### Speed distance time problems

   Posted in the Algebra Forum
   Replies: 1
   Last Post: July 27th 2011, 12:14 PM

2. ###### distance, speed and time problem/mixture and salary problems

   Posted in the Algebra Forum
   Replies: 3
   Last Post: July 24th 2010, 03:32 AM

3. ###### grade 10 word problems (speed, time, distance)

   Posted in the Algebra Forum
   Replies: 2
   Last Post: January 29th 2009, 04:38 AM

4. ###### speed distance time

   Posted in the Algebra Forum
   Replies: 2
   Last Post: January 5th 2009, 12:38 PM

5. ###### Help with speed/distance/time and d/dx?

   Posted in the Calculus Forum
   Replies: 2
   Last Post: December 8th 2008, 02:55 AM

#### Search Tags

difficult, distance, problems, speed, time

View Tag Cloud